@@ -2,6 +2,7 @@ from .base import Strategy, Guard, get_user
 from .jwt import JWTStrategy
 from .api_key import APIKeyStrategy
 from .slack import SlackStrategy
+from .password import PasswordStrategy
 from .error import AuthenticationError
 
 __all__ = [
@@ -11,5 +12,6 @@ __all__ = [
     JWTStrategy,
     APIKeyStrategy,
     SlackStrategy,
-    AuthenticationError
+    PasswordStrategy,
+    AuthenticationError,
 ]
\ No newline at end of file
