@@ -23,8 +23,9 @@ class JWTStrategy(Strategy):
         except InvalidTokenError:
             pass
 
-    def grant(self, request):
-        data = self.build_token(get_user())
+    def grant(self, user = None):
+        user = get_user() if user is None else user
+        data = self.build_token(user)
         if self._expiry is not None:
             data["exp"] = datetime.utcnow() + self._expiry
-        return jwt.encode(data, self._secret)
\ No newline at end of file
+        return jwt.encode(data, self._secret).decode("utf-8")
\ No newline at end of file
