@@ -16,7 +16,7 @@ class PasswordStrategy(Strategy):
         return split
 
     def get_hash(self, user):
-        return user["password"]
+        return user["password"].tobytes()
 
     def authenticate(self, state):
         pair = self.get_credentials()
@@ -25,6 +25,6 @@ class PasswordStrategy(Strategy):
         state.attempted = True
         email, password = pair
         user = self.get_user(email)
-        if user is None or not bcrypt.checkpw(password, self.get_hash(user)):
+        if user is None or not bcrypt.checkpw(password.encode("utf-8"), self.get_hash(user)):
             return
-        state.user = self.get_user(data)
\ No newline at end of file
+        state.user = user
\ No newline at end of file
